==> xmedcon-0.8.13.tbz: include/xmedcon/m-config.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: m-config.h.in                                                 *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : (X)MedCon template configuration header (configure)      *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: m-config.h.in,v 1.9 2003/06/08 22:27:25 enlf Exp $
 */

/*
   Copyright (C) 1997-2003 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef __M_CONFIG_H__
#define __M_CONFIG_H__

/* Define some version variables */
#define XMEDCON_MAJOR    (0)
#define XMEDCON_MINOR    (8)
#define XMEDCON_MICRO    (13)
#define XMEDCON_PRGR     "(X)MedCon"
#define XMEDCON_DATE     "15-Jun-2003"
#define XMEDCON_VERSION  "0.8.13"
#define XMEDCON_LIBVERS  "(X)MedCon 0.8.13 by Erik Nolf"

/* Define if format enabled */
#define MDC_INCLUDE_ACR  0
#define MDC_INCLUDE_GIF  0
#define MDC_INCLUDE_INW  0
#define MDC_INCLUDE_ANLZ 0
#define MDC_INCLUDE_CONC 0
#define MDC_INCLUDE_ECAT 0
#define MDC_INCLUDE_INTF 0
#define MDC_INCLUDE_DICM 0
#define MDC_INCLUDE_PNG  0

/* Define some machine dependencies */
#define MDC_WORDS_BIGENDIAN  0
#define MDC_SIZEOF_SHORT     2
#define MDC_SIZEOF_INT       4
#define MDC_SIZEOF_LONG      8
#define MDC_ENABLE_LONG_LONG 0

#if MDC_ENABLE_LONG_LONG
#define MDC_SIZEOF_LONG_LONG 
#endif


/* Define decompression program */
#define MDC_DECOMPRESS  "gunzip"

/* Define GLIB related stuff */
#define GLIBSUPPORTED 0

/* Define XMedCon related stuff */
#define XSUPPORTED 0
#if XSUPPORTED
 #define XMDCHELP "http://xmedcon.sourceforge.net"
 #define XMDCLUT  "<unused>/"
 #define XMDCRC   "<unused>/xmedconrc"
#endif

#endif

==> xmedcon-0.9.7.1.tbz: include/xmedcon/m-config.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: m-config.h.in                                                 *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : (X)MedCon template configuration header (configure)      *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: m-config.h.in,v 1.12 2004/01/04 22:36:16 enlf Exp $
 */

/*
   Copyright (C) 1997-2004 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef __M_CONFIG_H__
#define __M_CONFIG_H__

/* Define some version variables */
#define XMEDCON_MAJOR    (0)
#define XMEDCON_MINOR    (9)
#define XMEDCON_MICRO    (7.1)
#define XMEDCON_PRGR     "(X)MedCon"
#define XMEDCON_DATE     "23-Jun-2004"
#define XMEDCON_VERSION  "0.9.7.1"
#define XMEDCON_LIBVERS  "(X)MedCon 0.9.7.1 by Erik Nolf"

/* Define if format enabled */
#define MDC_INCLUDE_ACR  1
#define MDC_INCLUDE_GIF  1
#define MDC_INCLUDE_INW  1
#define MDC_INCLUDE_ANLZ 1
#define MDC_INCLUDE_CONC 1
#define MDC_INCLUDE_ECAT 1
#define MDC_INCLUDE_INTF 1
#define MDC_INCLUDE_DICM 1
#define MDC_INCLUDE_PNG  1

/* Define some machine dependencies */
#define MDC_WORDS_BIGENDIAN  0
#define MDC_SIZEOF_SHORT     2
#define MDC_SIZEOF_INT       4
#define MDC_SIZEOF_LONG      8
#define MDC_ENABLE_LONG_LONG 0

#if MDC_ENABLE_LONG_LONG
#define MDC_SIZEOF_LONG_LONG 
#endif


/* Define decompression program */
#define MDC_DECOMPRESS  "gunzip"

/* Define GLIB related stuff */
#define GLIBSUPPORTED 1

/* Define XMedCon related stuff */
#define XSUPPORTED 1
#if XSUPPORTED
#  define XMDCHELP "http://xmedcon.sourceforge.net"
#  ifdef _WIN32
#    define XMDCLUT  "C:\\Program Files\\XMedCon\\etc\\"
#    define XMDCRC   "C:\\Program Files\\XMedCon\\etc\\xmedconrc"
#  else
#    define XMDCLUT  "/usr/local/etc/"
#    define XMDCRC   "/usr/local/etc/xmedconrc"
#  endif
#endif

#endif
